# TaskResource

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**space_id** | **str** |  | [optional] 
**name** | **str** |  | [optional] 
**description** | **str** |  | [optional] 
**arguments** | **dict(str, object)** |  | [optional] 
**state** | **str** |  | [optional] 
**completed** | **str** |  | [optional] 
**queue_time** | **datetime** |  | [optional] 
**queue_time_expiry** | **datetime** |  | [optional] 
**start_time** | **datetime** |  | [optional] 
**last_updated_time** | **datetime** |  | [optional] 
**completed_time** | **datetime** |  | [optional] 
**server_node** | **str** |  | [optional] 
**duration** | **str** |  | [optional] 
**error_message** | **str** |  | [optional] 
**has_been_picked_up_by_processor** | **bool** |  | [optional] 
**is_completed** | **bool** |  | [optional] 
**finished_successfully** | **bool** |  | [optional] 
**has_pending_interruptions** | **bool** |  | [optional] 
**can_rerun** | **bool** |  | [optional] 
**has_warnings_or_errors** | **bool** |  | [optional] 
**last_modified_on** | **datetime** |  | [optional] 
**last_modified_by** | **str** |  | [optional] 
**links** | **dict(str, str)** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


